/* global describe it */
var chai = require('chai')
var plantumlEncoder = require('../lib/plantuml-encoder')

var expect = chai.expect

describe('plantuml-encoder', function () {
  describe('#encode()', function () {
    it('should encode "A -> B: Hello"', function () {
      var encoded = plantumlEncoder.encode('A -> B: Hello')
      expect(encoded).to.equal('SrJGjLDmibBmICt9oGS0')
    })
    it('should encode UTF-8 "A -> B: Hello/你好"', function () {
      var encoded = plantumlEncoder.encode('A -> B: Hello/你好')
      expect(encoded).to.equal('SrJGjLDmibBmICt9oTT_idV1qwLx0G00')
    })
    it('should encode Denzel', function () {
      var encoded = plantumlEncoder.encode('actor Denzel')
      expect(encoded).to.equal('IqmkoIzIS4dDgqhD0G00')
      //
      // SoWkIImgAStDASrBIKtBp4jDSKZDIm7o0G00
      // IqmkoIzIS4dDgqhD0G00
    })
  })
  describe('#decode()', function () {
    it('should decode "A -> B: Hello"', function () {
      var plain = 'A -> B: Hello'
      var crypt = 'SrJGjLDmibBmICt9oGS0'
      var decoded = plantumlEncoder.decode(crypt)
      expect(decoded).to.equal(plain)
    })
    it('should decode UTF-8 "A -> B: Hello/你好"', function () {
      var decoded = plantumlEncoder.decode('SrJGjLDmibBmICt9oTT_idV1qwLx0G00')
      expect(decoded).to.equal('A -> B: Hello/你好')
    })
    it('stuff', function () {
      // var decoded = plantumlEncoder.decode('SoWkIImgAStDuKfCBialKd19pQjApU5oICrB0Ge20000')
      var decoded = plantumlEncoder.decode('IqmkoIzIS4dDgqhD0G00')
      console.log(decoded)
      expect(decoded).to.equal('actor Denzel')
    })
  })
})
